@@ -56,7 +56,7 @@ ContactPrintThemeConfigureDialog::ContactPrintThemeConfigureDialog(QWidget *pare
     QLabel *lab = new QLabel(i18n("Default contact:"));
     lay->addWidget(lab);
 
-    mDefaultContact = new Akonadi::ContactEditor(Akonadi::ContactEditor::CreateMode, Akonadi::ContactEditor::VCardMode);
+    mDefaultContact = new Akonadi::AkonadiContactEditor(Akonadi::AkonadiContactEditor::CreateMode, Akonadi::AkonadiContactEditor::VCardMode);
     lay->addWidget(mDefaultContact);
 
     tab->addTab(w, i18n("General"));
@@ -157,4 +157,3 @@ void ContactPrintThemeConfigureDialog::writeConfig()
     group.writeEntry("defaultTemplate", mDefaultTemplate->toPlainText());
     mConfigureWidget->writeConfig();
 }
-
