@@ -23,12 +23,10 @@
 #include "config-grantleethemeeditor.h"
 #include <KSyntaxHighlighting/Repository>
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class TextEditorCompleter;
 }
-namespace GrantleeThemeEditor
-{
+namespace GrantleeThemeEditor {
 class GrantleePlainTextEditor : public KPIMTextEdit::PlainTextEditor
 {
     Q_OBJECT
@@ -39,7 +37,7 @@ public:
     void createCompleterList(const QStringList &extraCompletion);
 
 protected:
-    void keyPressEvent(QKeyEvent *e) Q_DECL_OVERRIDE;
+    void keyPressEvent(QKeyEvent *e) override;
 
 protected:
     KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter;
